#
# spec file for package xfwm4
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git
Name:           xfwm4
Version:        4.18.0
Release:        bp156.2.6
Summary:        Default Window Manager for the Xfce Desktop Environment
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/xfce/xfwm4/start
Source0:        https://archive.xfce.org/src/xfce/xfwm4/4.18/%{name}-%{version}.tar.bz2
Source1:        xfwm4.xml
BuildRequires:  exo-tools
BuildRequires:  fdupes
BuildRequires:  gdk-pixbuf-loader-rsvg
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  xfce4-dev-tools
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(libwnck-3.0) >= 3.14
BuildRequires:  pkgconfig(libxfce4kbd-private-3) >= 4.18.0
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.18.0
BuildRequires:  pkgconfig(libxfce4util-1.0)
BuildRequires:  pkgconfig(libxfconf-0) >= 4.18.0
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xpresent)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xrender)
Recommends:     %{name}-lang = %{version}
Suggests:       xfwm4-themes
Provides:       xfwm4-doc = %{version}
Obsoletes:      xfwm4-doc <= 4.8.3
Provides:       windowmanager

%description
xfwm4 is the default Xfce window manager which manages the placement of
application windows on the screen, provides beautiful window decorations,
manages workspaces or virtual desktops and natively supports multiscreen mode.
It provides its own compositing manager for true transparency and shadows. The
Xfce window manager also includes a keyboard shorcuts editor for user specific
commands and basic windows manipulations and provides a preferences dialog for
advanced tweaks.

%package branding-upstream
Summary:        Upstream Branding of xfwm4
Group:          System/GUI/XFCE
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
#BRAND: xfce4.xml: Determines a number of window manager settings including the
#BRAND: default theme and title bar font.
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for the xfwm4 window manager.

%lang_package

%prep
%autosetup

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode \
    --enable-compositor \
    --enable-xpresent
%else
%configure \
    --enable-compositor \
    --enable-xpresent
%endif
%make_build

%install
%make_install

install -D -p -m 644 %{SOURCE1} \
    %{buildroot}%{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml/xfwm4.xml

%suse_update_desktop_file xfce-wm-settings
%suse_update_desktop_file xfce-wmtweaks-settings
%suse_update_desktop_file xfce-workspaces-settings

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%if %{with git}
%doc example.gtkrc-2.0 AUTHORS COMPOSITOR NEWS NOTES TODO
%else
%doc example.gtkrc-2.0 AUTHORS COMPOSITOR NEWS TODO README.md
%endif
%license COPYING*
%{_bindir}/xfwm4
%{_bindir}/xfwm4-settings
%{_bindir}/xfwm4-tweaks-settings
%{_bindir}/xfwm4-workspace-settings
%dir %{_libdir}/xfce4/xfwm4
%{_libdir}/xfce4/xfwm4/helper-dialog
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/*/*.png
%{_datadir}/icons/hicolor/*/*/*.svg
%{_datadir}/themes/*
%{_datadir}/xfwm4

%files lang -f %{name}.lang

%files branding-upstream
%dir %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml
%config %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml/xfwm4.xml

%changelog
* Sun Dec 18 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update version to 4.18.0
  * Bump requirements for Xfce 4.18
  * Added functionality to move window to another monitor
  * Added radio buttons and checkboxes to window menu
  * bump copyright to 2022
  * Change dialog help and close button icons
  * cleanup: Don't use parenthesis when returning constants
  * client: Do not hide transients for group if above
  * client: Fix
  * client: Get the GdkDisplay from ScreenInfo
  * client: Handle removal of GTK_FRAME_EXTENTS
  * client: Move getSizeExcludingMargins()
  * client: No need to always reconfigure on monitor change
  * client: Preserve saved position on monitor change
  * client: Toggle from partial maximization to unmaximize
  * client: Update workarea only for windows with struts
  * client.c: fix a little typo
  * client.h: move STRUTS_SIZE to hints.h
  * common: xfwm_get_monitor_geometry() report fail via return code, fix potential NULL
  * compositor: Add support for adaptive vsync with GLX
  * compositor: Add throttled repaint
  * compositor: Clear root backing pixmap before use
  * compositor: Damage window when adding the opaque region
  * compositor: Disable GLX on mutli-screen (Zaphod)
  * compositor: Disable GLX vblank with virgl
  * compositor: Do not clear timeout on retry
  * compositor: Do not set deprecated compositor selection
  * compositor: fix ifdef
  * compositor: fix printf format strings
  * compositor: Fix repaint timeout
  * configure.ac.in: configure option to enable poswin
  * configure.ac.in: drop obsolete check for libSM
  * configure.ac.in: drop unused HAVE_CYGWIN conditional
  * configure.ac.in: fix obsolete AC_HEADER_STDC / obsolete checks
  * configure.ac.in: replace obsolete AC_HELP_STRING
  * display: check for XResQueryClientIds to enable XRes extension.
  * drop obsolete and unsupported KDE systray protocol
  * Drop subtitle and use symbolic close icon
  * Drop subtitle from workspace settings dialog
  * Fix build warnings
  * Fix intltool lock file bug in make distcheck
  * focus: Check for user focus for when passing focus
  * focus: Fix focus being lost on workspace switch
  * gitignore: add files generated by distcheck
  * icons: Check XGetGeometry() appropriate return value
  * icons: Gracefully handle non-existent icons
  * Make workspace setting workable with other window managers
  * Makefile.am: remove stale intltool-merge lockfile
  * menu: Small code cleanup
  * Merge branch 'drsudo/xfwm4-layerRadioBox'
  * netwm: Do not use _NET_WM_PING in multi-screen
  * netwm: Fix clientValidateNetStrut()
  * netwm.c: simplify and optimize struts array
  * placement: Add new function to compute the max space available
  * placement: Auto-maximize windows with both width and height
  * placement: clientMaxSpace() drop unused variable
  * placement: Compute struts using output scale
  * placement: Factorize max space computation
  * placement: Fix the initial position
  * placement: Ignore struts from windows on other monitors
  * placement: Remove the "same monitor" param
  * placement: Restack fullscreen window when necessary
  * placement: Small cleanup
  * placement: Use a GdkRectangle instead of multiple coords
  * placement: Windows on different screens cannot overlap
  * Post release tag bump
  * poswin: Fix location with client-side decorations
  * Remove redundant code
  * Replace stock icons
  * screen: Add a new API to get the screen max space
  * settings-dialogs: Remove ENABLE_NLS ifdefs
  * settings: Enable either windows wrap or tiling
  * settings: Fix untranslatable string
  * stacking: Above goes on top of fullscreen
  * startup-notification: Fix timeout computation
  * startup-notification: Reduce timeout to 10 seconds
  * Translation Updates
  * ui_style: drop unused getUIPangoContext()
  * updated NEWS
  * Use symbolic icons
  * wireframe: add window class hint to wireframes
  * workspace: Update maximized on struts change
  * xfce-wm-menu.png: Fix the 22x22 icon size
* Sun Jan 10 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Redacted changelog
* Sat Jan  9 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.16.1
  * Catch more XErrors (gxo#xfce/xfwm4#476, gxo#xfce/xfwm4#486)
  * Untile window before switching to fullscreen (gxo#xfce/xfwm4#478)
  * Allow interactive resizing with any keyboard modifier
    (gxo#xfce/xfwm4#487)
  * Do not prefer Xpresent on AMD/Radeon (gxo#xfce/xfwm4#490)
  * Use g_info/g_print instead of g_message for some message
  * Translation Updates
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.0
  - common: Avoid zero refresh rate for monitor
  - hints: Protect against XError from XGetTransientFor()
  - netwm: Allow above/below only for regular windows
  - netwm: Mark splashscreen as transient for groups
  - client: Complete client state even on different workspaces
  - build: Increase GTK+ requirement to 3.22
  - Add `cycle_minimized` option
  - compositor: Release overlay window last
  - compositor: Free GLX data when really using GLX
  - compositor: Remove useless trace message
  - compositor: Release current GLX context on teardown
  - display: Remove custom XError handler
  - compositor: Check for XError when adding windows
  - compositor: Trap XErrors when disabling compositor
  - main: Enable compositor by default
  - compositor: Remove automatic redirect support
  - main: Add short command line options
  - main: Add debug command line option
  - pixmap: Use a safer strncpy()
  - settings: Fix compiler warning
  - Remove useless autotools macros and Makefile targets
  - Use --enable-debug=yes when compiling from git
  - Revert "compositor: Do not damage on opaque region update"
  - themes: Use smaller, lighter shadows
  - compositor: Check if compositor is enabled
  - compositor: Avoid XError when disabling compositor
  - compositor: Warn for missing epoxy GL function
  - netwm: Do not raise window if activate is set to none
  - Remove GSourceFunc casts
  - compositor: Fix build with older epoxy versions
  - settings: Add 'Always on top' to the double click action
  - Settings: Remove default alphabetical sorting of keyboard shortcuts
    Closes: gxo#xfce/xfwm4#451 (Disable initial sorting of keyboard shortcuts)
  - compositor: Handle XFixes XError
  - compositor: Add support for GL_ARB_sync
  - compositor: Return early if a Present swap is pending
  - debug: Fix build in debug mode
  - compositor: Fix compilation issue with Xpresent
  - compositor: Log fence and GLX swap time in debug mode
  - compositor: Move fence sync to redraw_glx
  - compositor: Move fence triggered to its own function
  - compositor: Set swap control if possible
  - compositor: Adjust to the actual number of buffers
  - compositor: Use a GLX drawable per buffer
  - client: Allow transients for group to be minimized
  - settings: Add a UI option for desktop zooming
  - themes: Remove title shadow
  - themes: Adjust shadows size/opacity
  - client: Make above/below consistent
  - compositor: Limit damage region to the screen
  - compositor: Optimize repaint without vblank
  - compositor: Only accumulate damage with multiple buffers
  - compositor: Copy entire content for GLX buffers
  - xsync: Handle XError
  - compositor: Ignore opaque region for shaded windows
  - compositor: Clip opaque region against window shape
  - client: Protect against XError in XKillClient()
  - compositor: Do not damage on opaque region update
  - compositor: Opaque region applies to client window
  - compositor: Reuse client size
  - client: Toggle tiling on key shortcut
  - client: Small cleanup
  - Add README.md to EXTRA_DIST
  - client: Keep tiled size of windows
  - compositor: No need to update compositor window on configure
  - compositor: Limit opaque region clipping to window extents
  - compositor: Damage on opaque region update only if visible
  - client: Send synthetic configure on force redraw
  - Post release tag bump
  - Translation Updates
- Updates from version 4.15.3
  * Add support for opaque regions in the compositor
  * Make cursor zoom optional (gxo#xfce/xfwm4#439)
  * Remove the deprecated options "--daemon"
  * Disable Xi2 support by default
  * Add column sorting in settings
  * Optimize window matching in the compositor with a hash table
  * Add more XErrors traps
  * Translation updates
- Updates from version 4.15.2
  * Add support for opaque regions in the compositor
  * Make cursor zoom optional (gxo#xfce/xfwm4#439)
  * Remove the deprecated options "--daemon"
  * Disable Xi2 support by default
  * Add column sorting in settings
  * Optimize window matching in the compositor with a hash table
  * Add more XErrors traps
- Updates from 4.15.1
  * Show tabwin only on primary monitor if set
  * Fix an error leak in compositor (gxo#xfce/xfwm4#351)
  * Fix compositor selection atom misuse
  * Prefer zero initialized memory allocation functions
  * Use g_slice allocator for compositor windows
* Mon Nov  2 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.14.6
  * Add more XErrors traps
  * Translation updates
* Sun Aug  9 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.14.5
  * Fix an error leak in compositor (gxo#xfce/xfwm4#351)
  * Fix compositor selection atom misuse
* Sat Aug  1 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.14.4
  * Fix a crash on FreeBSD (gxo#xfce/xfwm4#411)
  * Fix compilation warning due to g_type_class_add_private deprecation
* Sun Jul 26 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.14.3
  * Add support for XRes X11 extension to get the PID of sandboxed apps
  * Fix use-after-free of settings strings (gxo#xfce/xfwm4#406)
  * More XError traps (gxo#xfce/xfwm4#405)
  * Translation updates
* Fri May  1 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.14.2
  * Prefer GLX on AMD (bxo#16716)
  * Fix compositor without required X11 extensions (bxo#16713)
  * Fix window decorations without XRender extension (bxo#16713)
  * Avoid grabbing the keyboard with Alt-Tab to work around a bug
    in Qt with XInput2 valuators (bxo#16708)
  * Automatically update window title fonts on scale change
  * Fix a regression with title font size at scale 2 (bxo#16711)
  * Fix an X error with XShape (bxo#16383)
  * Translation updates
* Mon Apr 13 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.14.1
  * Restore “Always below” menu options (bxo#15884)
  * Fix a crash with GL or high CPU usage without any monitor
    (bxo#15852)
  * Fix raise delay (bxo#15974)
  * Fix translucent wireframe repaint (bxo#15966)
  * Fix hostname not showing initially when running apps remotely
    (bxo#15984)
  * Avoid drawing server-side shadows on maximized windows
    (bxo#16381)
  * Add keywords to settings dialogs desktop definitions
    (bxo#16621)
  * Fix Dnd of decoration buttons with embedded settings dialog
    (bxo#13861)
  * Blacklist SVGA3D GL renderer (bxo#16274)
  * Fix window title alignment (bxo#16067)
  * Restore window state when moving a maximized window
    (bxo#16348)
  * Fix pointer interactions with clients grabbing the pointer
    (bxo#16347)
  * Fix GTimeVal deprecation (bxo#16644)
  * Fix window selection vs. hovering in tabwin (bxo#16382)
  * Improve vblank mode auto-selection (GL/XPresent)
  * Fix transients pulling their parents from lower layers
    (bxo#15891)
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.14.0
  * settings-dialog: Replace GtkStock buttons
  * Translation Updates
- Fixed up spec file
* Sat Jul 27 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.13.4
  * Fix GL texture filter (bxo#15676)
  * Fix zooming without GL
  * Place windows on current monitor (bxo#14959)
  * Fix raising of parent transients (bxo#15580)
  * Enable root pixmap with compositor (bxo#15709)
* Thu Jul  4 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Enable Xpresent support
* Sun Jun 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.13.3
  * Update CSS for tabwinb only on theme change
  * HiDPI: Use GTK3 scaling attributes for window titles
  * HiDPI: Adjust default theme with scale
  * Fix initial pointer location when zooming
  * Fix double-click distance setting
  * Allow the top of the frame to be cropped when maximised
    (bxo#14470)
  * Update default theme to use maximized cropping
  * Fix build without compositor (bxo#15432)
  * Improved GLX support with NVIDIA proprietary/closed source driver
    (bxo#15453)
  * Compositor updates with GLX
  * Small optimization with zoom on GLX
  * Increase X11 client priority of xfwm4
  * Change default compositor background to plain black
  * Fallback to resource class name for icons
    (bxo#15510)
  * Clear shortcut in settings-dialog when removed (bxo#12802)
  * Remove icons from window menu
  * Fix regression with maximized window (bxo#15638)
  * I18n: Update translations
* Sat May 18 2019 maurizio.galli@gmail.com
- Update to version 4.13.2
  - Fix flickering with GLX backend (bxo#14564, bxo#13519)
  - Fix monitor geometry with scaled UI (bxo#14566)
  - Fix issue with Android Virtual Device emulator (bxo#12206)
  - Fix XI2 mask (bxo#14695)
  - Fix preview with shaded windows (bxo#14899)
  - Fix tabwin placement with scaled UI (bxo#14931)
  - Add xfconf setting for selecting permanent vblank method
  - Fix maximization with GTK clients using size increments (bxo#13954)
  - Add style class to tabwin modes
  - Fix crash/stack smash in startup-notification on some architectures
    (bxo#15028)
  - Avoid crash with button layout setting (bxo#14606)
  - Raise on activate only with raise-on-focus (bxo#14656)
  - Fix use after release of client picture with hidden (bxo#14990)
  - Fix monitor output size update (bxo#15085)
  - Allow transients to be minimized (bxo#14953)
  - Raise all transients together (bxo#15303)
  - Fix menu alignment with scaled UI
  - Fix a regression where the client would remain visible if
    closed while cycling (bxo#15318)
  - Withdraw the frame before the client window (bxo#15061)
  - Revert to GLX as default vblank method (bxo#15325)
  - Reduce repaint timeout (bxo#14335)
  - Fix support for 1bpp icons
  - Use cairo for pixmaps and masks
  - Allow hiding windows using NET_WM_STATE_HIDDEN (bxo#15356)
  - Fix size increment with scaled UI
  - Various compositor improvements and optimizations with GLX
  - Check for appropriate XSync version and increase xfwm4 priority
  - Adjust zoom update based on monitor refresh rate (bxo#1539)
  - Fix window type for broken clients (bxo#15399)
  - Fix pointer enter/leave with decoration buttons (bxo#14741)
  - New default theme
  - Translation updates
- Switch source to released tarball instead of git master
- Fixed bcond for building with git sources and released tarballs
- Stop trying to install Gilouche, Sonar and Kelabu themes.
  These themes are no longer provided by this package.
- Cleaned up spec file
* Fri May 17 2019 maurizio.galli@gmail.com
- Update to version 4.13.1~git229.add14bfa:
  * I18n: Update translation gl (100%%).
  * I18n: Update translation da (100%%).
  * compositor: Remove unused variables
  * compositor: Rework XPresent error handler
  * compositor: Set present pending only on success
  * compositor: Disable XPresent on any error
  * compositor: Fix xpresent
  * client: Check for enter/leave window on button events
  * I18n: Update translation da (100%%).
  * hints: Remove unused variables
* Wed May  8 2019 maurizio.galli@gmail.com
- Update to version 4.13.1~git134.558fb547:
  * I18n: Update translation pt_BR (100%%).
  * compositor: Ignore errors when destroying windows
  * display: Do not sync before trap pop
  * display: Log serial and minor code
  * I18n: Update translation gl (100%%).
  * poswin: Small cleanup
  * moveresize: Size increment depends on scale
  * poswin: Use our own GdkWindow for scale
  * poswin: Fix position with scale
  * compositor: reduce timeout to 1ms
* Tue Apr 30 2019 maurizio.galli@gmail.com
- Update to version 4.13.1~git118.10b15b1a:
  * compositor: Reduce repaint timeout to 2ms
  * compositor: reinstate “--vblank” option
  * compositor: Revert to GLX as default vblank method (again)
  * client: Withdraw the frame before the client window
  * menu: Avoid XError with gtk
  * client: Do not ping client when killing it
  * cycling: Remove client if destroyed while cycling
  * I18n: Update translation ko (100%%).
  * client: Fix regression with MWM hints
  * Add gitignore
- Changes from 4.13.0
  * Add support for VSYNC using either Present or OpenGL
  * Support for scaled cursor when zooming
  * Daemon mode is now deprecated (--daemon has no effect)
  * Bug fixes and I18n improvements
- Clean up spec file
- Added conditional %%bcond_with git for easier maintanance when
  using Xfce git master branch
* Tue Jan  8 2019 Stasiek Michalski <hellcp@mailbox.org>
- Remove old themes, moved to gtk2 repos of the themes
* Mon Aug  6 2018 seife+obs@b1-systems.com
- update to 4.12.5:
  - client: Check GTK_HIDE_TITLEBAR_WHEN_MAXIMIZED
  - client: Check when GTK_FRAME_EXTENTS has changed (bxo#14511)
  - netwm: Fix adding maximized state (bxo#14514)
  - fix typo in clientMoveTile (bxo#14181)
  - screen: Use computed screen size instead of xlib
  - client: Make sure to redraw when removing maximized (bxo#13954)
  - Fix logic error in bottom struts validation (bxo#13964)
  - client: Maximize on expected output (bxo#13284)
  - screen: Fix broken monitor index (bxo#13608)
  - Use ximerama indices for _NET_WM_FULLSCREEN_MONITORS (bxo#9351)
  - placement: Use primary monitor as default (bxo#13454)
* Wed Apr 19 2017 seife+obs@b1-systems.com
- update to version 4.12.4
  - moveresize: Cancel move/resize if client is gone (bxo#13344)
  - netwm: Make docks and spash screens appear focused
  - placement: Relocate dialogs only (bxo#12587)
  - Force application win_gravity to NorthWestGravity (bxo#12617)
  - keyboard: Re-apply modifiers masks
  - keyboard: Ignore unsupported modifiers (bxo#10760)
  - don't block display events when time is set backwards (bxo#10184)
  - Fix rendering with 30-bit colormap (bxo#12344)
  - Only check for known buttons in _NET_WM_MOVERESIZE
* Sat May 16 2015 gber@opensuse.org
- update to version 4.12.3
  - configure: check for exo-csource (bxo#11870)
  - focus: Ignore zero timestamp from s/n (bxo#11822)
  - events: do not monitor SubstructureNotifyMask (bxo#11893)
  - Fix compiler warnings
* Sun Mar 15 2015 gber@opensuse.org
- update to version 4.12.2
  - quick release to fix a mishmash between width and height
    introduced in 4.12.1 (bxo#11700)
* Sun Mar 15 2015 gber@opensuse.org
- update to version 4.12.1
  - Fix issue with XRandR (bxo#11059, bxo#11683, bxo#11695)
  - Rework struts support to be more error proof
  - Fix smart placement and windows overlapping (bxo#11671)
  - Fix window positioning and gravity (bxo#11670, bxo#11693)
  - Fix issue with _NET_REQUEST_FRAME_EXTENTS being ignored
    (blocking for GLFW apps) (bxo#11664)
  - Check class hint name for same applications (bxo#11685)
  - Make horizontal scrolling/window opacity optional (bxo#10372)
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.0
  - add support for gtk window menu
  - avoid window decorations in preview
  - clean-up compositor state in case of error
  - compute struts based on reported screen size
  - do not tile windows if they don't fit in
  - enable compositing by default
  - enable window preview in cycling by default
  - fix build with compositor disabled
  - fix window menu positioning with CSD
  - fix window preview disappearing on themes reload
  - reuse client macros in compositor
  - revert "Optionally remove frame on tiling as well"
  - set maximum valid struts values
  - use larger window preview by default
  - use opaque background color for preview
  - use smallest screen area
  - translation updates
* Sat Feb 14 2015 gber@opensuse.org
- update to version 4.11.3
  - add a zoom_desktop xfconf setting
  - add corner tiling
  - add support for extended XSync counter
  - add support for GTK frame extents
  - add support for GTK hide titlebar on maximize
  - add support for NET_WM_STATE_FOCUSED
  - add titleless maximization feature
  - allow color substitution in themerc
  - allow cycling during drag'n drop
  - allow shadow under dock ARGB windows
  - allow tiling and workspace wrap on move
  - changed wireframe to cairo drawing when using the compositor
  - fix cycle vs. focus follow mouse
  - fix fullscreen mode not working correctly for QT apps)
  - fix gravity on configure request
  - fix keyboard shortcuts after keyboard layout changes
  - fix maximizing when window is tiled vertically or horizontally
  - fix maximum host name length.
  - fix opacity being reset on theme change
  - fix reparenting with compositor
  - fix selection with mouse in multi-monitor alt-tab dialog
  - fix size increment
  - limit parallel pointer moves before wrapping
  - new default window decoration themes (including HDPI and xHDPI)
  - on canceled move, restore all maximizations states
  - optionally remove frame on tiling as well
  - optionnally use window preview in tabwin
  - prevent CSD windows from being moved too far up
  - remove horizontal tyling on move
  - remove maximize button from non-resizable windows
  - remove restore-on-move option
  - send debug messages to a log file
  - update desktop geometry on xrandr events
  - use cairo wireframe for move/resize
  - use correct type on platforms where time_t is 64bits like OpenBSD
  - use source indication in activate window
  - use the correct drm/dri device on OpenBSD
  - workaround for NET_WORKAREA with multimonitor
  - lot of translations updates
* Thu Oct  2 2014 crrodriguez@opensuse.org
- Do not buildRequire metapackage xorg-x11-devel only
  exactly the libraries that are required.
* Sat Jul 26 2014 gber@opensuse.org
- update to version 4.11.2
  - improve auto-maximize fn to maximize windows which size is
    equal to the available size
  - restore original window size after untiling (Bug 8765)
  - add improved tab-win dialog
  - translation updates
* Thu May  1 2014 gber@opensuse.org
- remove xfwm4-fix-bug-in-workspace-deletion.patch file
* Thu May  1 2014 gber@opensuse.org
- update to version 4.11.1
  - remove unnecessary clipping of the rootPicture
  - if making a solid fill, use XRenderCreateSolidFill
  - repaint the screen when background changes
  - ignore when root atoms are unset
  - implement zooming
  - add tweak setting to toggle roll up feature (bxo#10563)
  - disable roll up feature by default (bxo#10563)
  - fix duplicated accelerators (bxo#5256)
  - do not write empty session files
  - optimize smart placement (bxo#5785)
  - improvements in accelerator handling
  - remove unmaintained translations
  - make the xfwm4-settings dialog use less height
  - fixup padding in keyboard shortcuts tab
  - autotools updates
  - add Vsync support for the compositor (bxo#8898)
  - translation updates
* Sun May  5 2013 gber@opensuse.org
- update to version 4.10.1
  - autotools updates
  - small optimization in shadow loop
  - some small optimizations in placement code
  - do not write empty session files
  - fix wrong debug message
  - fix crash in settings dialog with wrong title alignment value
  - implement NET_WM_MOVERESIZE_CANCEL message
  - translation updates
- removed obsolete
  xfwm4-implement-net_wm_moveresize_cancel-message.patch,
  xfwm4-fix-crash-in-settings-dialog.patch,
  xfwm4-fix-bug-in-workspace-deletion.patch
* Sat Aug 18 2012 gber@opensuse.org
- add xfwm4-implement-net_wm_moveresize_cancel-message.patch in
  order to implement NET_WM_MOVERESIZE_CANCEL message as gtk+-3.4
  now uses it (bxo#8949)
- add xfwm4-fix-crash-in-settings-dialog.patch in order to fix a
  crash in settings dialog with wrong title alignment value
  (bxo#9108)
- add xfwm4-fix-bug-in-workspace-deletion.patch which reverts part
  of git commit 8637c3a as this breaks deletetion of current
  workspace (bxo#8827)
* Sun Apr 29 2012 gber@opensuse.org
- update to version 4.10.0
  - translation updates
* Thu Apr 19 2012 gber@opensuse.org
- obsolete xfwm4-doc properly
* Sat Apr 14 2012 gber@opensuse.org
- recommend %%{name}-lang
* Sat Apr 14 2012 gber@opensuse.org
- update to version 4.9.1
  - improve tiling
  - reduce tiling distance
  - keep pointer position relative to the window being moved
  - set spacing to avoid overlap with some themes
  - add workspace settings in a notebook
  - improve workspace dialog subtitle/comment
  - generate default icon during make dist
  - update FSF address in settings dialogs
  - add missing license
  - restore button press/release mask as removing it breaks switching
    workspaces with scroll wheel
  - add UI option to WM tweaks for tiling
  - resize fullscreen windows on screen size changes
  - don't use deprecated g_str(n)casecmp
  - translation updates
* Sun Apr  8 2012 gber@opensuse.org
- update to version 4.9.0
  - add tiling feature
  - navigate with arrows in task switcher
  - show dialogs in settings category
  - do not cancel pending focus transition and use actual
    meaningful timestamp to avoid setting focus on wrong window in
    focus follow mouse
  - remove docbook documentation
  - remove older themes from main package (moved to xfwm4-themes
    now)
  - add patch for themeable tab-window
  - use themeable icons for the settings manager and the menu,
    rework the default icons for the settings manager and the
    window menu and add SVG version
  - reintroduce the double-click timeout
  - drop AC_PROG_LIBTOOL in favor of LT_PREREQ and LT_INIT
  - simply double click detection logic
  - add special icons for the button layout in settings
  - remove some XFlush() calls
  - upon restart, restore the previous selected workspace
  - improve horizontal/vertical maximization toggle so that
    de-maximizing in either direction while fully maximized gives
    the expected maximization result
  - change the default theme to differentiate from 4.8
  - update mouse cursor theme and size dynamically
  - optimize transients for group evaluation while withdrawing#
    windows
  - increase timeout for other WM to exit with "--replace",
  - rework focus and fullscreen windows to make xfwm4 simpler and
    more predictable
  - get rid or of old GNOME 1.x protocol
  - get rif of legacy fullscreen emulation
  - translation updates
* Thu Mar 29 2012 gber@opensuse.org
- split-off -lang subpackage
- correct dependencies
- do not regenerate documentation
- specfile cleanup
* Mon Feb 20 2012 gber@opensuse.org
- add missing dependency on xorg-x11-devel
* Mon Dec 19 2011 gber@opensuse.org
- update to version 4.8.3
  - do not exit the move/resize loop when just any key is pressed
    unless the operation is triggered via the keyboard
  - reverting from desktop view may not focus the top most window
  - recompute window's position/maximization state even if the
    overall size of the screen hasn't changed as the actual layout
    of the monitors may have changed nevertheless
  - check for both forward and backward cycling modifier to be
    released before exiting the cycle loop
  - fix a couple of memory leaks
  - fix some events being lost causing the tabwin window to remain
    sometimes after the key has been released
  - fix crash when workspace count is set to negative values
  - fix crash in signal handler
  - fix a bug with transients for group (including utility windows)
    being withdrawn as many times as parent windows where in the
    group, causing utility windows to disapear when switching
    workspaces
  - do not allow applications to change the win layer on dialogs to
    prevent dialogs to be unreachable in some Java based
    applications
  - do not enforce the size increment only if the size request
    comes from the application itself
- dropped obsolete xfwm4-4.8.2-careful-layer-manipulation.patch,
  xfwm4-4.8.2-fix-disappearing-transient-windows.patch, and
  xfwm4-4.8.2-fix-resizing.patch
* Tue Oct 25 2011 gber@opensuse.org
- tweak Kelabu theme colors
* Sun Oct 23 2011 gber@opensuse.org
- added Kelabu xfwm4 theme
* Thu Oct 20 2011 gber@opensuse.org
- install HTML documentation under /usr/share/xfce4/xfwm4/html
* Tue Oct 18 2011 gber@opensuse.org
- added xfwm4-4.8.2-fix-disappearing-transient-windows.patch which
  fixes a problem with transient windows disapearing when switching
  workspaces
* Fri Oct 14 2011 gber@opensuse.org
- split off -doc subpackage
* Tue Oct 11 2011 gber@opensuse.org
- added xfwm4-4.8.2-careful-layer-manipulation.patch in order to
  ignore size increment if a resize request comes from an
  application itself (backported from upstream git)
- added xfwm4-4.8.2-fix-resizing.patch in oder to be more careful
  when allowing applications to manipulate the window layer by
  themselves
- do not package INSTALL file
* Fri Oct  7 2011 gber@opensuse.org
- copy the right source file
* Fri Sep 23 2011 gber@opensuse.org
- update to version 4.8.2
  - relax resize wrt to size increments
  - allow menu shortcut to work even for non-decorated windows
  - keep window fully visible on screen on size request
  - bugfixes
  - translation updates
- dropped obsolete
  xfwm4-4.8.1-fix-panel-plugins-not-receiving-focus.patch,
  xfwm4-4.8.1-always-initialize-display-session.patch
* Tue Sep 20 2011 gber@opensuse.org
- added xfwm4-4.8.1-fix-panel-plugins-not-receiving-focus.patch in
  order to fix panel plugins not receiving focus in focus follow
  mouse mode (backported from upstream git)
- added xfwm4-4.8.1-always-initialize-display-session.patch which
  ensures the display struct's session member is always initialized
  in order to prevent crashes when quitting (backported from
  upstream git)
* Fri Feb 18 2011 gber@opensuse.org
- fixed glitch in Gilouche xfwm4 theme
* Fri Feb 18 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Thu Feb 17 2011 gber@opensuse.org
- fixed glitch in Sonar xfwm4 theme
* Thu Feb  3 2011 gber@opensuse.org
- update to version 4.8.1
  - bugfixes
  - translation updates
  - allow the use of pixmaps without alpha channels for themes
* Wed Feb  2 2011 gber@opensuse.org
- added Sonar and Gilouche themes here for now
- added xfwm4-branding-upstream subpackage
- remove installed Makefile.am files
- build documentation
* Mon Jan 17 2011 gber@opensuse.org
- update to version 4.8.0
  - no changes
* Tue Jan 11 2011 gber@opensuse.org
- removed dependency on xfconf
* Tue Dec 28 2010 gber@opensuse.org
- do not install documentation in /usr/share/doc
- improved summary/description
- show compiler output
- removed obsolete build dependencies
- require xfconf
- remove unsupported locales
* Sun Dec  5 2010 prusnak@opensuse.org
- updated to 4.7.3
  - Panel won't focus entries in focus follow mode (bug #6649).
  - Adjusted sizes when a maximized window is undecorated (bug #6543).
  - Unshade windows when given focus with Alt-Tab (bug #5931).
  - Fix hang when closing a submenu (bug #6562).
  - New theme for 4.8.
  - Focus-follows-mouse activate/raise should not do focus (bug #4679).
  - Translation updates (pt, pt_BR, it).
- updated to 4.7.2
  - Fix corrupted button layouts by obtaining the button IDs correctly
    (bug #6824).
  - Bump the GTK+ dependency to 2.14 which is the minimum version
    required for Xfce 4.8.
  - Properly implement session handling (bug #6330).
  - Make the settings dialog smaller so it fits on netbooks screens.
  - Depend on libxfce4ui 4.7.5 for crucial fix in the
    save-state-extended signal.
  - Translation updates (it, gl, pt, da, de, kk, hu, zh_CN).
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Fri Nov 26 2010 andrea@opensuse.org
- new upstream version 4.7.1
* Sun Jul 18 2010 bernhard@bwalle.de
- update to 4.6.2
  o Build fixes for GIT.
  o Fix mixed RTL/LTR text not rendering properly in title and tabwin.
  o Place windows on top of stack even when not focused in focus
    follow mouse (bug #5479).
  o Increase menu button height and redice width (bug #5567).
  o Do not set the "demand attention" flag when the window is already
    focused.
  o Keep windows entirely visible on screen change (bug #5795).
  o Various compilation warnings fixed.
  o Compute screen size based on each monitor size and layout and
    avoid using reported size (bug #5795).
  o Reloading settings on keysochanged signal is a huge overhead and
    complete nonsense (bug #5964).
  o Recent Xorg drivers disable the output when the lid is closed,
    leaving no active monitor, in that case simply ignore the event to
    avoid messing with windows' positions (bug #6209).
  o Add linkage to libm when compositor is used (bug #6231).
  o Check for invalid type for GValue to avoid a crash (bug #6195).
  o Allow only regular windows to be placed either above or below.
  o Translation updates (cs, el, es, gl, it, pl, pt, sv, tr, uk, lv,
    ur, ur_PK, ro, ru, nl, ug).
* Mon Jul 20 2009 dominique-obs@leuenberger.net
- Follow change of %%%%{_libexecdir}
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 4.6.1
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 4.6.0 (Xfce 4.6.0 release)
* Tue Nov 18 2008 pnemec@suse.cz
- call update_desktop_file macro on desktop files [bnc#445722]
* Wed Oct 29 2008 bwalle@suse.de
- update to 4.4.3
  o Fix automaximize on move
  o Remove trailing \0 in UTF-8 strings, that causes libwnck to
    rightfully complain that NET_WM_NAME contains invalid UTF-8
  o Exit on SelectionClear event so that xfwm4 exits even with WM
    who do not send a ClientMessage event such as Openbox
  o Backport overlay and compositor support from trunk
  o Filter out grab/ungrab events so we don't end up redrawing the
    frame twice
  o Set monitor when positionning menu
  o Reduce flickering during resize
  o Fix NET_WM_STATE claiming maximization vertical and horizontal
    even if only horizontal of vertical is actually set
  o Loosen the rule that prevents an application from iconifying
    itself when skip_taskbar is set
  o Rework visual depth selection of the frame window
  o Add support for NET_MOVERESIZE_WINDOW
  o Take gravity bit into account in configure resize only requests
    to comply with standard
  o Add client windows to save set to avoid loosing all windows in
    case of crash
  o Use guint32 instead of Time internally to avoid potential
    issues in 64bits
  o Add a "--replace" command line option to replace ICCCM2
    compliant window managers
* Tue Dec  4 2007 prusnak@suse.cz
- use %%find_lang macro
* Mon Dec  3 2007 bwalle@suse.de
- update to 4.4.2
  o Be more relax with transients, allow transients to be sticky
    independently of their parent window
  o Fix xfwm4 hanging with gtk+-2.11.x
  o Plug a leak in mouse button grab when changing theme.
  o Fix dialogs and modals without parents not being automatically
    centered like before
  o Fix modifier mask not working with all keymaps
  o Fix wrong count of key shortcuts causing switch to last workspace
    on modifier key press if no window is focused
  o Fix spec file missing from the tar ball causing 'make dist' to
    fail.
  o Fix strict bound checking causing wrong window to be focused in
    focus follow mouse
  o Transients for group shouldn't apply to other transients, or it
    breaks stacking for some apps, noticeably mozilla "save as"
    dialog...
  o Fix typo breaking compilation on systems without XShape 1.1
    support.
* Mon Aug 13 2007 bwalle@suse.de
- fix possible hangs with Gtk 2.11 (Xfce Bug #3346)
* Sat Jun 23 2007 bwalle@suse.de
- replaced group 'System/GUI/Other' by 'System/GUI/Xfce'
* Wed May 30 2007 bwalle@suse.de
- disable KDE systray support, it's broken for applications that
  want to hide their application icon like the volume unmounter
* Wed Apr 18 2007 prusnak@suse.cz
- removed invalid line from spec file
* Wed Apr 11 2007 prusnak@suse.cz
- fixed compilation on older Xorg/XFree86 (fix-typo.patch)
* Tue Apr 10 2007 bwalle@suse.de
- update to 4.4.1
  o Add support for shape input with XShape extension 1.1.
  o Make the title button in the xfwm4 settings manager dragable.
  o Fix a misinterpretation of ICCCM about when to send a synthetic
    configureNotify event.
  o Add new hidden option to instruct xfwm4 not to bring window
    back on current workspace when activated.
  o Place splash screen windows on the normal layer, so that
    dialogs that get mapped during startup have a chance to be
    placed above the splash screen.
  o Raise focused window on workspace switch.
  o Sort Z-order on workspace change.
  o Fix the small lag before icon update at first map and when
    updating all frames at once.
  o Use timeout for frame redraw, check actual WM name changes to
    work around apps that falsely update their WM name property.
  o Updated translations: Hungaria, Catalan, Italian, Polish,
    German, Japanese, Turkish, Ukrainian, Dutch, Chinese
    (simplified) and French.
  o New translations: Albanian (Besnik Bleta), English
    (Jeff Bailes).
* Sun Feb 25 2007 bwalle@suse.de
- removed KDE systray support (deprecated)
* Mon Jan 29 2007 pnemec@suse.cz
- removed providing %%name from packages #236139
* Sun Jan 21 2007 bwalle@suse.de
- upgraded to 4.4.0
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 21 2006 cthiel@suse.de
- update to 4.2.3.2
* Mon Aug  1 2005 cthiel@suse.de
- fixed Requires
* Wed May 18 2005 cthiel@suse.de
- update to 4.2.2
- dropped xfwm4-gcc4.diff
* Tue Apr 19 2005 cthiel@suse.de
- update to 4.2.1
- enabled compositor
- added xfwm4-gcc4.diff
* Thu Feb 10 2005 adrian@suse.de
- install session desktop file
* Thu Nov  4 2004 mmj@suse.de
- locale rename: no -> nb
* Wed May 19 2004 ltinkl@suse.cz
- fix packaging the docu as well
* Mon May 17 2004 ltinkl@suse.cz
- initial version
